// server.js
const swaggerUi = require('swagger-ui-express');
const path = require('path');
const jsonServer = require('json-server');
const yaml = require('js-yaml');
const fs = require('fs');
const routes = require('./routes');
var multer = require('multer');

var storage = multer.diskStorage({
    destination: function (req, file, cb) {
        cb(null, path.join(__dirname, 'public/uploads'));
    },
    filename: function (req, file, cb) {
        cb(null, file.fieldname + '-' + Date.now());
    }
});

var upload = multer({ storage });

const server = jsonServer.create();
const router = jsonServer.router(path.join(__dirname, 'db.json'));
const middlewares = jsonServer.defaults();

const swaggerDocument = yaml.load(fs.readFileSync('./swagger-academicid.yaml', 'utf8'));

server.get('/', (req, res) => {
    res.redirect('/api-docs')
})

server.use(
    '/api-docs',
    swaggerUi.serve,
    swaggerUi.setup(swaggerDocument)
);

server.use(middlewares);
server.use(upload.any());
server.use(jsonServer.rewriter(routes));
server.use(router);
server.listen(3000, () => {
    console.log('JSON Server is running')
});
